@@ -1,14 +1,6 @@
-/*
-* Copyright 2006 Sony Computer Entertainment Inc.
-*
-* Licensed under the MIT Open Source License, for details please see license.txt or the website
-* http://www.opensource.org/licenses/mit-license.php
-*
-*/ 
-
 #include <dae.h>
 #include <dae/daeDom.h>
-#include <1.4/dom/domSkew.h>
+#include <1.5/dom/domSkew.h>
 #include <dae/daeMetaCMPolicy.h>
 #include <dae/daeMetaSequence.h>
 #include <dae/daeMetaChoice.h>
@@ -17,7 +9,7 @@
 #include <dae/daeMetaElementAttribute.h>
 
 
-namespace ColladaDOM141 {
+namespace ColladaDOM150 {
 daeElementRef
 domSkew::create(DAE& dae)
 {
@@ -51,7 +43,7 @@ domSkew::registerElement(DAE& dae)
 	{
 		daeMetaAttribute *ma = new daeMetaAttribute;
 		ma->setName( "sid" );
-		ma->setType( dae.getAtomicTypes().get("xsNCName"));
+		ma->setType( dae.getAtomicTypes().get("Sid"));
 		ma->setOffset( daeOffsetOf( domSkew , attrSid ));
 		ma->setContainer( meta );
 	
@@ -64,4 +56,4 @@ domSkew::registerElement(DAE& dae)
 	return meta;
 }
 
-} // ColladaDOM141
+} // ColladaDOM150
